==> qtwayland-everywhere-opensource-src-5.15.17.zip: qtwayland-everywhere-src-5.15.17/src/hardwareintegration/compositor/xcomposite_share/xcompositebuffer.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWaylandCompositor module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "xcompositebuffer.h"

QT_BEGIN_NAMESPACE

XCompositeBuffer::XCompositeBuffer(Window window, const QSize &size,
                                   struct ::wl_client *client, uint32_t id)
    : QtWaylandServer::wl_buffer(client, id, 1)
    , mWindow(window)
    , mOrigin(QWaylandSurface::OriginBottomLeft)
    , mSize(size)
{
}

void XCompositeBuffer::buffer_destroy_resource(Resource *)
{
    delete this;
}

void XCompositeBuffer::buffer_destroy(Resource *resource)
{
    wl_resource_destroy(resource->handle);
}

Window XCompositeBuffer::window()
{
    return mWindow;
}

QT_END_NAMESPACE

==> qtwayland-everywhere-opensource-src-6.2.12.zip: qtwayland-everywhere-src-6.2.12/src/hardwareintegration/compositor/xcomposite_share/xcompositebuffer.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWaylandCompositor module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "xcompositehandler.h"
#include "xcompositebuffer.h"

QT_BEGIN_NAMESPACE

XCompositeBuffer::XCompositeBuffer(Window window, const QSize &size,
                                   struct ::wl_client *client, uint32_t id, XCompositeHandler *handler)
    : QtWaylandServer::wl_buffer(client, id, 1)
    , mWindow(window)
    , mOrigin(QWaylandSurface::OriginBottomLeft)
    , mSize(size)
    , mHandler(handler)
{
}

void XCompositeBuffer::buffer_destroy_resource(Resource *resource)
{
    mHandler->removeBuffer(resource->handle);
    delete this;
}

void XCompositeBuffer::buffer_destroy(Resource *resource)
{
    wl_resource_destroy(resource->handle);
}

Window XCompositeBuffer::window()
{
    return mWindow;
}

QT_END_NAMESPACE
